@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -36,8 +34,7 @@ from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.translate_v3.services.translation_service import pagers
 from google.cloud.translate_v3.types import translation_service
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import TranslationServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import TranslationServiceGrpcTransport
 from .transports.grpc_asyncio import TranslationServiceGrpcAsyncIOTransport
@@ -60,7 +57,7 @@ class TranslationServiceClientMeta(type):
     def get_transport_class(
         cls, label: str = None,
     ) -> Type[TranslationServiceTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -83,7 +80,8 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -117,7 +115,8 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -134,7 +133,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -153,23 +152,24 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     @property
     def transport(self) -> TranslationServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            TranslationServiceTransport: The transport used by the client instance.
+            TranslationServiceTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def glossary_path(project: str, location: str, glossary: str,) -> str:
-        """Return a fully-qualified glossary string."""
+        """Returns a fully-qualified glossary string."""
         return "projects/{project}/locations/{location}/glossaries/{glossary}".format(
             project=project, location=location, glossary=glossary,
         )
 
     @staticmethod
     def parse_glossary_path(path: str) -> Dict[str, str]:
-        """Parse a glossary path into its component segments."""
+        """Parses a glossary path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/glossaries/(?P<glossary>.+?)$",
             path,
@@ -178,7 +178,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -191,7 +191,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -202,7 +202,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -213,7 +213,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -224,7 +224,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -238,12 +238,12 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, TranslationServiceTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the translation service client.
+        """Instantiates the translation service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -298,9 +298,10 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -312,12 +313,14 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -332,8 +335,8 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -346,6 +349,10 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=(
+                    Transport == type(self).get_transport_class("grpc")
+                    or Transport == type(self).get_transport_class("grpc_asyncio")
+                ),
             )
 
     def translate_text(
@@ -452,7 +459,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
                 This corresponds to the ``source_language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -488,10 +494,8 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, translation_service.TranslateTextRequest):
             request = translation_service.TranslateTextRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if target_language_code is not None:
@@ -589,7 +593,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
                 This corresponds to the ``content`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -618,10 +621,8 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, translation_service.DetectLanguageRequest):
             request = translation_service.DetectLanguageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if model is not None:
@@ -714,7 +715,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
                 This corresponds to the ``display_language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -743,10 +743,8 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, translation_service.GetSupportedLanguagesRequest):
             request = translation_service.GetSupportedLanguagesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if model is not None:
@@ -791,7 +789,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         Args:
             request (google.cloud.translate_v3.types.BatchTranslateTextRequest):
                 The request object. The batch translation request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -809,7 +806,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a translation_service.BatchTranslateTextRequest.
         # There's no risk of modifying the input as we've already verified
@@ -867,7 +863,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
                 This corresponds to the ``glossary`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -899,10 +894,8 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, translation_service.CreateGlossaryRequest):
             request = translation_service.CreateGlossaryRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if glossary is not None:
@@ -955,7 +948,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -986,10 +978,8 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, translation_service.ListGlossariesRequest):
             request = translation_service.ListGlossariesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1037,7 +1027,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1066,10 +1055,8 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, translation_service.GetGlossaryRequest):
             request = translation_service.GetGlossaryRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1112,7 +1099,6 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1144,10 +1130,8 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, translation_service.DeleteGlossaryRequest):
             request = translation_service.DeleteGlossaryRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
