@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,23 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.translate_v3beta1.types import translation_service
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import TranslationServiceTransport, DEFAULT_CLIENT_INFO
 from .grpc import TranslationServiceGrpcTransport
 
@@ -55,7 +52,7 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
     def create_channel(
         cls,
         host: str = "translate.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -82,13 +79,15 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -96,7 +95,7 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
         self,
         *,
         host: str = "translate.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
@@ -106,11 +105,13 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -146,6 +147,8 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
@@ -169,7 +172,6 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-
         else:
             if api_mtls_endpoint:
                 host = api_mtls_endpoint
@@ -199,6 +201,7 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
             scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
         if not self._grpc_channel:
@@ -365,7 +368,8 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
     def batch_translate_text(
         self,
     ) -> Callable[
-        [translation_service.BatchTranslateTextRequest], Awaitable[operations.Operation]
+        [translation_service.BatchTranslateTextRequest],
+        Awaitable[operations_pb2.Operation],
     ]:
         r"""Return a callable for the batch translate text method over gRPC.
 
@@ -393,7 +397,7 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
             self._stubs["batch_translate_text"] = self.grpc_channel.unary_unary(
                 "/google.cloud.translation.v3beta1.TranslationService/BatchTranslateText",
                 request_serializer=translation_service.BatchTranslateTextRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["batch_translate_text"]
 
@@ -402,7 +406,7 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
         self,
     ) -> Callable[
         [translation_service.BatchTranslateDocumentRequest],
-        Awaitable[operations.Operation],
+        Awaitable[operations_pb2.Operation],
     ]:
         r"""Return a callable for the batch translate document method over gRPC.
 
@@ -430,7 +434,7 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
             self._stubs["batch_translate_document"] = self.grpc_channel.unary_unary(
                 "/google.cloud.translation.v3beta1.TranslationService/BatchTranslateDocument",
                 request_serializer=translation_service.BatchTranslateDocumentRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["batch_translate_document"]
 
@@ -438,7 +442,7 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
     def create_glossary(
         self,
     ) -> Callable[
-        [translation_service.CreateGlossaryRequest], Awaitable[operations.Operation]
+        [translation_service.CreateGlossaryRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the create glossary method over gRPC.
 
@@ -459,7 +463,7 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
             self._stubs["create_glossary"] = self.grpc_channel.unary_unary(
                 "/google.cloud.translation.v3beta1.TranslationService/CreateGlossary",
                 request_serializer=translation_service.CreateGlossaryRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_glossary"]
 
@@ -527,7 +531,7 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
     def delete_glossary(
         self,
     ) -> Callable[
-        [translation_service.DeleteGlossaryRequest], Awaitable[operations.Operation]
+        [translation_service.DeleteGlossaryRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the delete glossary method over gRPC.
 
@@ -549,7 +553,7 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
             self._stubs["delete_glossary"] = self.grpc_channel.unary_unary(
                 "/google.cloud.translation.v3beta1.TranslationService/DeleteGlossary",
                 request_serializer=translation_service.DeleteGlossaryRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_glossary"]
 
