@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -78,14 +75,12 @@ class TranslateTextGlossaryConfig(proto.Message):
             nsensitive. Default value is false if missing.
     """
 
-    glossary = proto.Field(proto.STRING, number=1)
-
-    ignore_case = proto.Field(proto.BOOL, number=2)
+    glossary = proto.Field(proto.STRING, number=1,)
+    ignore_case = proto.Field(proto.BOOL, number=2,)
 
 
 class TranslateTextRequest(proto.Message):
     r"""The request message for synchronous translation.
-
     Attributes:
         contents (Sequence[str]):
             Required. The content of the input in string
@@ -163,28 +158,20 @@ class TranslateTextRequest(proto.Message):
             for more information.
     """
 
-    contents = proto.RepeatedField(proto.STRING, number=1)
-
-    mime_type = proto.Field(proto.STRING, number=3)
-
-    source_language_code = proto.Field(proto.STRING, number=4)
-
-    target_language_code = proto.Field(proto.STRING, number=5)
-
-    parent = proto.Field(proto.STRING, number=8)
-
-    model = proto.Field(proto.STRING, number=6)
-
+    contents = proto.RepeatedField(proto.STRING, number=1,)
+    mime_type = proto.Field(proto.STRING, number=3,)
+    source_language_code = proto.Field(proto.STRING, number=4,)
+    target_language_code = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(proto.STRING, number=8,)
+    model = proto.Field(proto.STRING, number=6,)
     glossary_config = proto.Field(
         proto.MESSAGE, number=7, message="TranslateTextGlossaryConfig",
     )
-
-    labels = proto.MapField(proto.STRING, proto.STRING, number=10)
+    labels = proto.MapField(proto.STRING, proto.STRING, number=10,)
 
 
 class TranslateTextResponse(proto.Message):
     r"""
-
     Attributes:
         translations (Sequence[google.cloud.translate_v3beta1.types.Translation]):
             Text translation responses with no glossary applied. This
@@ -199,7 +186,6 @@ class TranslateTextResponse(proto.Message):
     """
 
     translations = proto.RepeatedField(proto.MESSAGE, number=1, message="Translation",)
-
     glossary_translations = proto.RepeatedField(
         proto.MESSAGE, number=3, message="Translation",
     )
@@ -207,7 +193,6 @@ class TranslateTextResponse(proto.Message):
 
 class Translation(proto.Message):
     r"""A single translation response.
-
     Attributes:
         translated_text (str):
             Text translated into the target language.
@@ -231,12 +216,9 @@ class Translation(proto.Message):
             The ``glossary_config`` used for this translation.
     """
 
-    translated_text = proto.Field(proto.STRING, number=1)
-
-    model = proto.Field(proto.STRING, number=2)
-
-    detected_language_code = proto.Field(proto.STRING, number=4)
-
+    translated_text = proto.Field(proto.STRING, number=1,)
+    model = proto.Field(proto.STRING, number=2,)
+    detected_language_code = proto.Field(proto.STRING, number=4,)
     glossary_config = proto.Field(
         proto.MESSAGE, number=3, message="TranslateTextGlossaryConfig",
     )
@@ -244,7 +226,6 @@ class Translation(proto.Message):
 
 class DetectLanguageRequest(proto.Message):
     r"""The request message for language detection.
-
     Attributes:
         parent (str):
             Required. Project or location to make a call. Must refer to
@@ -291,20 +272,15 @@ class DetectLanguageRequest(proto.Message):
             for more information.
     """
 
-    parent = proto.Field(proto.STRING, number=5)
-
-    model = proto.Field(proto.STRING, number=4)
-
-    content = proto.Field(proto.STRING, number=1, oneof="source")
-
-    mime_type = proto.Field(proto.STRING, number=3)
-
-    labels = proto.MapField(proto.STRING, proto.STRING, number=6)
+    parent = proto.Field(proto.STRING, number=5,)
+    model = proto.Field(proto.STRING, number=4,)
+    content = proto.Field(proto.STRING, number=1, oneof="source",)
+    mime_type = proto.Field(proto.STRING, number=3,)
+    labels = proto.MapField(proto.STRING, proto.STRING, number=6,)
 
 
 class DetectedLanguage(proto.Message):
     r"""The response message for language detection.
-
     Attributes:
         language_code (str):
             The BCP-47 language code of source content in
@@ -314,14 +290,12 @@ class DetectedLanguage(proto.Message):
             this language.
     """
 
-    language_code = proto.Field(proto.STRING, number=1)
-
-    confidence = proto.Field(proto.FLOAT, number=2)
+    language_code = proto.Field(proto.STRING, number=1,)
+    confidence = proto.Field(proto.FLOAT, number=2,)
 
 
 class DetectLanguageResponse(proto.Message):
     r"""The response message for language detection.
-
     Attributes:
         languages (Sequence[google.cloud.translate_v3beta1.types.DetectedLanguage]):
             A list of detected languages sorted by
@@ -336,7 +310,6 @@ class DetectLanguageResponse(proto.Message):
 
 class GetSupportedLanguagesRequest(proto.Message):
     r"""The request message for discovering supported languages.
-
     Attributes:
         parent (str):
             Required. Project or location to make a call. Must refer to
@@ -376,16 +349,13 @@ class GetSupportedLanguagesRequest(proto.Message):
             (PBMT) model.
     """
 
-    parent = proto.Field(proto.STRING, number=3)
-
-    display_language_code = proto.Field(proto.STRING, number=1)
-
-    model = proto.Field(proto.STRING, number=2)
+    parent = proto.Field(proto.STRING, number=3,)
+    display_language_code = proto.Field(proto.STRING, number=1,)
+    model = proto.Field(proto.STRING, number=2,)
 
 
 class SupportedLanguages(proto.Message):
     r"""The response message for discovering supported languages.
-
     Attributes:
         languages (Sequence[google.cloud.translate_v3beta1.types.SupportedLanguage]):
             A list of supported language responses. This
@@ -419,30 +389,25 @@ class SupportedLanguage(proto.Message):
             Can be used as target language.
     """
 
-    language_code = proto.Field(proto.STRING, number=1)
-
-    display_name = proto.Field(proto.STRING, number=2)
-
-    support_source = proto.Field(proto.BOOL, number=3)
-
-    support_target = proto.Field(proto.BOOL, number=4)
+    language_code = proto.Field(proto.STRING, number=1,)
+    display_name = proto.Field(proto.STRING, number=2,)
+    support_source = proto.Field(proto.BOOL, number=3,)
+    support_target = proto.Field(proto.BOOL, number=4,)
 
 
 class GcsSource(proto.Message):
     r"""The Google Cloud Storage location for the input content.
-
     Attributes:
         input_uri (str):
             Required. Source data URI. For example,
             ``gs://my_bucket/my_object``.
     """
 
-    input_uri = proto.Field(proto.STRING, number=1)
+    input_uri = proto.Field(proto.STRING, number=1,)
 
 
 class InputConfig(proto.Message):
     r"""Input configuration for BatchTranslateText request.
-
     Attributes:
         mime_type (str):
             Optional. Can be "text/plain" or "text/html". For ``.tsv``,
@@ -471,8 +436,7 @@ class InputConfig(proto.Message):
             ``.html``, which is treated as a single large chunk of text.
     """
 
-    mime_type = proto.Field(proto.STRING, number=1)
-
+    mime_type = proto.Field(proto.STRING, number=1,)
     gcs_source = proto.Field(
         proto.MESSAGE, number=2, oneof="source", message="GcsSource",
     )
@@ -480,7 +444,6 @@ class InputConfig(proto.Message):
 
 class GcsDestination(proto.Message):
     r"""The Google Cloud Storage location for the output content.
-
     Attributes:
         output_uri_prefix (str):
             Required. There must be no files under 'output_uri_prefix'.
@@ -489,12 +452,11 @@ class GcsDestination(proto.Message):
             returned.
     """
 
-    output_uri_prefix = proto.Field(proto.STRING, number=1)
+    output_uri_prefix = proto.Field(proto.STRING, number=1,)
 
 
 class OutputConfig(proto.Message):
     r"""Output configuration for BatchTranslateText request.
-
     Attributes:
         gcs_destination (google.cloud.translate_v3beta1.types.GcsDestination):
             Google Cloud Storage destination for output content. For
@@ -582,7 +544,6 @@ class OutputConfig(proto.Message):
 
 class DocumentInputConfig(proto.Message):
     r"""A document translation request input config.
-
     Attributes:
         content (bytes):
             Document's content represented as a stream of
@@ -604,18 +565,15 @@ class DocumentInputConfig(proto.Message):
             -  application/vnd.openxmlformats-officedocument.spreadsheetml.sheet
     """
 
-    content = proto.Field(proto.BYTES, number=1, oneof="source")
-
+    content = proto.Field(proto.BYTES, number=1, oneof="source",)
     gcs_source = proto.Field(
         proto.MESSAGE, number=2, oneof="source", message="GcsSource",
     )
-
-    mime_type = proto.Field(proto.STRING, number=4)
+    mime_type = proto.Field(proto.STRING, number=4,)
 
 
 class DocumentOutputConfig(proto.Message):
     r"""A document translation request output config.
-
     Attributes:
         gcs_destination (google.cloud.translate_v3beta1.types.GcsDestination):
             Optional. Google Cloud Storage destination for the
@@ -682,13 +640,11 @@ class DocumentOutputConfig(proto.Message):
     gcs_destination = proto.Field(
         proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
     )
-
-    mime_type = proto.Field(proto.STRING, number=3)
+    mime_type = proto.Field(proto.STRING, number=3,)
 
 
 class TranslateDocumentRequest(proto.Message):
     r"""A document translation request.
-
     Attributes:
         parent (str):
             Required. Location to make a regional call.
@@ -763,32 +719,24 @@ class TranslateDocumentRequest(proto.Message):
             for more information.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    source_language_code = proto.Field(proto.STRING, number=2)
-
-    target_language_code = proto.Field(proto.STRING, number=3)
-
+    parent = proto.Field(proto.STRING, number=1,)
+    source_language_code = proto.Field(proto.STRING, number=2,)
+    target_language_code = proto.Field(proto.STRING, number=3,)
     document_input_config = proto.Field(
         proto.MESSAGE, number=4, message="DocumentInputConfig",
     )
-
     document_output_config = proto.Field(
         proto.MESSAGE, number=5, message="DocumentOutputConfig",
     )
-
-    model = proto.Field(proto.STRING, number=6)
-
+    model = proto.Field(proto.STRING, number=6,)
     glossary_config = proto.Field(
         proto.MESSAGE, number=7, message="TranslateTextGlossaryConfig",
     )
-
-    labels = proto.MapField(proto.STRING, proto.STRING, number=8)
+    labels = proto.MapField(proto.STRING, proto.STRING, number=8,)
 
 
 class DocumentTranslation(proto.Message):
     r"""A translated document message.
-
     Attributes:
         byte_stream_outputs (Sequence[bytes]):
             The array of translated documents. It is
@@ -807,16 +755,13 @@ class DocumentTranslation(proto.Message):
             empty.
     """
 
-    byte_stream_outputs = proto.RepeatedField(proto.BYTES, number=1)
-
-    mime_type = proto.Field(proto.STRING, number=2)
-
-    detected_language_code = proto.Field(proto.STRING, number=3)
+    byte_stream_outputs = proto.RepeatedField(proto.BYTES, number=1,)
+    mime_type = proto.Field(proto.STRING, number=2,)
+    detected_language_code = proto.Field(proto.STRING, number=3,)
 
 
 class TranslateDocumentResponse(proto.Message):
     r"""A translated document response message.
-
     Attributes:
         document_translation (google.cloud.translate_v3beta1.types.DocumentTranslation):
             Translated document.
@@ -841,13 +786,10 @@ class TranslateDocumentResponse(proto.Message):
     document_translation = proto.Field(
         proto.MESSAGE, number=1, message="DocumentTranslation",
     )
-
     glossary_document_translation = proto.Field(
         proto.MESSAGE, number=2, message="DocumentTranslation",
     )
-
-    model = proto.Field(proto.STRING, number=3)
-
+    model = proto.Field(proto.STRING, number=3,)
     glossary_config = proto.Field(
         proto.MESSAGE, number=4, message="TranslateTextGlossaryConfig",
     )
@@ -855,7 +797,6 @@ class TranslateDocumentResponse(proto.Message):
 
 class BatchTranslateTextRequest(proto.Message):
     r"""The batch translation request.
-
     Attributes:
         parent (str):
             Required. Location to make a call. Must refer to a caller's
@@ -920,28 +861,20 @@ class BatchTranslateTextRequest(proto.Message):
             for more information.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    source_language_code = proto.Field(proto.STRING, number=2)
-
-    target_language_codes = proto.RepeatedField(proto.STRING, number=3)
-
-    models = proto.MapField(proto.STRING, proto.STRING, number=4)
-
+    parent = proto.Field(proto.STRING, number=1,)
+    source_language_code = proto.Field(proto.STRING, number=2,)
+    target_language_codes = proto.RepeatedField(proto.STRING, number=3,)
+    models = proto.MapField(proto.STRING, proto.STRING, number=4,)
     input_configs = proto.RepeatedField(proto.MESSAGE, number=5, message="InputConfig",)
-
     output_config = proto.Field(proto.MESSAGE, number=6, message="OutputConfig",)
-
     glossaries = proto.MapField(
         proto.STRING, proto.MESSAGE, number=7, message="TranslateTextGlossaryConfig",
     )
-
-    labels = proto.MapField(proto.STRING, proto.STRING, number=9)
+    labels = proto.MapField(proto.STRING, proto.STRING, number=9,)
 
 
 class BatchTranslateMetadata(proto.Message):
     r"""State metadata for the batch translation operation.
-
     Attributes:
         state (google.cloud.translate_v3beta1.types.BatchTranslateMetadata.State):
             The state of the operation.
@@ -971,14 +904,10 @@ class BatchTranslateMetadata(proto.Message):
         CANCELLED = 5
 
     state = proto.Field(proto.ENUM, number=1, enum=State,)
-
-    translated_characters = proto.Field(proto.INT64, number=2)
-
-    failed_characters = proto.Field(proto.INT64, number=3)
-
-    total_characters = proto.Field(proto.INT64, number=4)
-
-    submit_time = proto.Field(proto.MESSAGE, number=5, message=timestamp.Timestamp,)
+    translated_characters = proto.Field(proto.INT64, number=2,)
+    failed_characters = proto.Field(proto.INT64, number=3,)
+    total_characters = proto.Field(proto.INT64, number=4,)
+    submit_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
 
 
 class BatchTranslateResponse(proto.Message):
@@ -1005,20 +934,15 @@ class BatchTranslateResponse(proto.Message):
             is set to true.
     """
 
-    total_characters = proto.Field(proto.INT64, number=1)
-
-    translated_characters = proto.Field(proto.INT64, number=2)
-
-    failed_characters = proto.Field(proto.INT64, number=3)
-
-    submit_time = proto.Field(proto.MESSAGE, number=4, message=timestamp.Timestamp,)
-
-    end_time = proto.Field(proto.MESSAGE, number=5, message=timestamp.Timestamp,)
+    total_characters = proto.Field(proto.INT64, number=1,)
+    translated_characters = proto.Field(proto.INT64, number=2,)
+    failed_characters = proto.Field(proto.INT64, number=3,)
+    submit_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
 
 
 class GlossaryInputConfig(proto.Message):
     r"""Input configuration for glossaries.
-
     Attributes:
         gcs_source (google.cloud.translate_v3beta1.types.GcsSource):
             Required. Google Cloud Storage location of glossary data.
@@ -1055,7 +979,6 @@ class GlossaryInputConfig(proto.Message):
 
 class Glossary(proto.Message):
     r"""Represents a glossary built from user provided data.
-
     Attributes:
         name (str):
             Required. The resource name of the glossary. Glossary names
@@ -1081,7 +1004,6 @@ class Glossary(proto.Message):
 
     class LanguageCodePair(proto.Message):
         r"""Used with unidirectional glossaries.
-
         Attributes:
             source_language_code (str):
                 Required. The BCP-47 language code of the input text, for
@@ -1093,13 +1015,11 @@ class Glossary(proto.Message):
                 GlossaryTerm.language_code.
         """
 
-        source_language_code = proto.Field(proto.STRING, number=1)
-
-        target_language_code = proto.Field(proto.STRING, number=2)
+        source_language_code = proto.Field(proto.STRING, number=1,)
+        target_language_code = proto.Field(proto.STRING, number=2,)
 
     class LanguageCodesSet(proto.Message):
         r"""Used with equivalent term set glossaries.
-
         Attributes:
             language_codes (Sequence[str]):
                 The BCP-47 language code(s) for terms defined in the
@@ -1108,30 +1028,23 @@ class Glossary(proto.Message):
                 GlossaryTerm.language_code.
         """
 
-        language_codes = proto.RepeatedField(proto.STRING, number=1)
-
-    name = proto.Field(proto.STRING, number=1)
+        language_codes = proto.RepeatedField(proto.STRING, number=1,)
 
+    name = proto.Field(proto.STRING, number=1,)
     language_pair = proto.Field(
         proto.MESSAGE, number=3, oneof="languages", message=LanguageCodePair,
     )
-
     language_codes_set = proto.Field(
         proto.MESSAGE, number=4, oneof="languages", message=LanguageCodesSet,
     )
-
     input_config = proto.Field(proto.MESSAGE, number=5, message="GlossaryInputConfig",)
-
-    entry_count = proto.Field(proto.INT32, number=6)
-
-    submit_time = proto.Field(proto.MESSAGE, number=7, message=timestamp.Timestamp,)
-
-    end_time = proto.Field(proto.MESSAGE, number=8, message=timestamp.Timestamp,)
+    entry_count = proto.Field(proto.INT32, number=6,)
+    submit_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,)
 
 
 class CreateGlossaryRequest(proto.Message):
     r"""Request message for CreateGlossary.
-
     Attributes:
         parent (str):
             Required. The project name.
@@ -1139,37 +1052,33 @@ class CreateGlossaryRequest(proto.Message):
             Required. The glossary to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     glossary = proto.Field(proto.MESSAGE, number=2, message="Glossary",)
 
 
 class GetGlossaryRequest(proto.Message):
     r"""Request message for GetGlossary.
-
     Attributes:
         name (str):
             Required. The name of the glossary to
             retrieve.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class DeleteGlossaryRequest(proto.Message):
     r"""Request message for DeleteGlossary.
-
     Attributes:
         name (str):
             Required. The name of the glossary to delete.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListGlossariesRequest(proto.Message):
     r"""Request message for ListGlossaries.
-
     Attributes:
         parent (str):
             Required. The name of the project from which
@@ -1212,18 +1121,14 @@ class ListGlossariesRequest(proto.Message):
             performed.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
-
-    filter = proto.Field(proto.STRING, number=4)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
+    filter = proto.Field(proto.STRING, number=4,)
 
 
 class ListGlossariesResponse(proto.Message):
     r"""Response message for ListGlossaries.
-
     Attributes:
         glossaries (Sequence[google.cloud.translate_v3beta1.types.Glossary]):
             The list of glossaries for a project.
@@ -1239,8 +1144,7 @@ class ListGlossariesResponse(proto.Message):
         return self
 
     glossaries = proto.RepeatedField(proto.MESSAGE, number=1, message="Glossary",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class CreateGlossaryMetadata(proto.Message):
@@ -1271,11 +1175,9 @@ class CreateGlossaryMetadata(proto.Message):
         CANCELLING = 4
         CANCELLED = 5
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     state = proto.Field(proto.ENUM, number=2, enum=State,)
-
-    submit_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
+    submit_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
 
 
 class DeleteGlossaryMetadata(proto.Message):
@@ -1306,11 +1208,9 @@ class DeleteGlossaryMetadata(proto.Message):
         CANCELLING = 4
         CANCELLED = 5
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     state = proto.Field(proto.ENUM, number=2, enum=State,)
-
-    submit_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
+    submit_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
 
 
 class DeleteGlossaryResponse(proto.Message):
@@ -1330,16 +1230,13 @@ class DeleteGlossaryResponse(proto.Message):
             is set to true.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    submit_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
-
-    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
+    name = proto.Field(proto.STRING, number=1,)
+    submit_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
 
 
 class BatchTranslateDocumentRequest(proto.Message):
     r"""The BatchTranslateDocument request.
-
     Attributes:
         parent (str):
             Required. Location to make a regional call.
@@ -1396,22 +1293,16 @@ class BatchTranslateDocumentRequest(proto.Message):
             keyed by target language code.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    source_language_code = proto.Field(proto.STRING, number=2)
-
-    target_language_codes = proto.RepeatedField(proto.STRING, number=3)
-
+    parent = proto.Field(proto.STRING, number=1,)
+    source_language_code = proto.Field(proto.STRING, number=2,)
+    target_language_codes = proto.RepeatedField(proto.STRING, number=3,)
     input_configs = proto.RepeatedField(
         proto.MESSAGE, number=4, message="BatchDocumentInputConfig",
     )
-
     output_config = proto.Field(
         proto.MESSAGE, number=5, message="BatchDocumentOutputConfig",
     )
-
-    models = proto.MapField(proto.STRING, proto.STRING, number=6)
-
+    models = proto.MapField(proto.STRING, proto.STRING, number=6,)
     glossaries = proto.MapField(
         proto.STRING, proto.MESSAGE, number=7, message="TranslateTextGlossaryConfig",
     )
@@ -1419,7 +1310,6 @@ class BatchTranslateDocumentRequest(proto.Message):
 
 class BatchDocumentInputConfig(proto.Message):
     r"""Input configuration for BatchTranslateDocument request.
-
     Attributes:
         gcs_source (google.cloud.translate_v3beta1.types.GcsSource):
             Google Cloud Storage location for the source input. This can
@@ -1451,7 +1341,6 @@ class BatchDocumentInputConfig(proto.Message):
 
 class BatchDocumentOutputConfig(proto.Message):
     r"""Output configuration for BatchTranslateDocument request.
-
     Attributes:
         gcs_destination (google.cloud.translate_v3beta1.types.GcsDestination):
             Google Cloud Storage destination for output content. For
@@ -1556,30 +1445,20 @@ class BatchTranslateDocumentResponse(proto.Message):
             is set to true.
     """
 
-    total_pages = proto.Field(proto.INT64, number=1)
-
-    translated_pages = proto.Field(proto.INT64, number=2)
-
-    failed_pages = proto.Field(proto.INT64, number=3)
-
-    total_billable_pages = proto.Field(proto.INT64, number=4)
-
-    total_characters = proto.Field(proto.INT64, number=5)
-
-    translated_characters = proto.Field(proto.INT64, number=6)
-
-    failed_characters = proto.Field(proto.INT64, number=7)
-
-    total_billable_characters = proto.Field(proto.INT64, number=8)
-
-    submit_time = proto.Field(proto.MESSAGE, number=9, message=timestamp.Timestamp,)
-
-    end_time = proto.Field(proto.MESSAGE, number=10, message=timestamp.Timestamp,)
+    total_pages = proto.Field(proto.INT64, number=1,)
+    translated_pages = proto.Field(proto.INT64, number=2,)
+    failed_pages = proto.Field(proto.INT64, number=3,)
+    total_billable_pages = proto.Field(proto.INT64, number=4,)
+    total_characters = proto.Field(proto.INT64, number=5,)
+    translated_characters = proto.Field(proto.INT64, number=6,)
+    failed_characters = proto.Field(proto.INT64, number=7,)
+    total_billable_characters = proto.Field(proto.INT64, number=8,)
+    submit_time = proto.Field(proto.MESSAGE, number=9, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=10, message=timestamp_pb2.Timestamp,)
 
 
 class BatchTranslateDocumentMetadata(proto.Message):
     r"""State metadata for the batch translation operation.
-
     Attributes:
         state (google.cloud.translate_v3beta1.types.BatchTranslateDocumentMetadata.State):
             The state of the operation.
@@ -1627,24 +1506,17 @@ class BatchTranslateDocumentMetadata(proto.Message):
         CANCELLED = 5
 
     state = proto.Field(proto.ENUM, number=1, enum=State,)
-
-    total_pages = proto.Field(proto.INT64, number=2)
-
-    translated_pages = proto.Field(proto.INT64, number=3)
-
-    failed_pages = proto.Field(proto.INT64, number=4)
-
-    total_billable_pages = proto.Field(proto.INT64, number=5)
-
-    total_characters = proto.Field(proto.INT64, number=6)
-
-    translated_characters = proto.Field(proto.INT64, number=7)
-
-    failed_characters = proto.Field(proto.INT64, number=8)
-
-    total_billable_characters = proto.Field(proto.INT64, number=9)
-
-    submit_time = proto.Field(proto.MESSAGE, number=10, message=timestamp.Timestamp,)
+    total_pages = proto.Field(proto.INT64, number=2,)
+    translated_pages = proto.Field(proto.INT64, number=3,)
+    failed_pages = proto.Field(proto.INT64, number=4,)
+    total_billable_pages = proto.Field(proto.INT64, number=5,)
+    total_characters = proto.Field(proto.INT64, number=6,)
+    translated_characters = proto.Field(proto.INT64, number=7,)
+    failed_characters = proto.Field(proto.INT64, number=8,)
+    total_billable_characters = proto.Field(proto.INT64, number=9,)
+    submit_time = proto.Field(
+        proto.MESSAGE, number=10, message=timestamp_pb2.Timestamp,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
